/*
 *  /MathJax-v2/localization/ast/FontWarnings.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("ast","FontWarnings",{version:"2.7.9",isLoaded:true,strings:{webFont:"MathJax ta usando fontes basaes en web p'amosar les matem\u00E1tiques d'esta p\u00E1xina. Lleva un tiempu descargales, de manera que la p\u00E1xina apaecer\u00E1 m\u00E1s r\u00E1pidamente si instala direutamente les fontes matem\u00E1tiques na carpeta de fontes del so sistema.",imageFonts:"MathJaz ta usando les sos fontes d'imaxe en cuenta de fontes llocales o basaes en web. Esto fai que la composici\u00F3n seya m\u00E1s lenta de lo normal, y les matem\u00E1tiques podr\u00EDen nun imprimise a la resoluci\u00F3n completa de la impresora.",noFonts:"MathJax nun pue alcontrar una tipograf\u00EDa que pueda usar p'amosar les espresiones matem\u00E1tiques, y nun hai disponibles fontes d'imaxe, de mou que va volver a car\u00E1uteres Unicode xen\u00E9ricos esperando que'l so restolador pueda amosalos. Algunos car\u00E1uteres podr\u00EDen nun vese correutamente o, seique, podrien nun vese n'absoluto.",webFonts:"La mayor\u00EDa de restoladores modernos permiten que les fontes se descarguen de la web. Si anueva a una versi\u00F3n m\u00E1s moderna del restolador (o si cambia de restolador) podr\u00EDa ameyorar la calid\u00E1 de les espresiones matem\u00E1tiques d'esta p\u00E1xina.",fonts:"MathJax pue usar tanto la [tipograf\u00EDa STIX](%1) como la [tipograf\u00EDa TeX MathJax](%2). Descargue y instale una d'estes tipograf\u00EDes p'ameyorar la so esperiencia con MathJax.",STIXPage:"Esta p\u00E0xina ta dise\u00F1ada pa usar la [tipograf\u00EDa STIX](%1). Descargue ya instale esta tipograf\u00EDa p'ameyorar la so esperiencia con MathJax.",TeXPage:"Esta p\u00E0xina ta dise\u00F1ada pa usar la [tipograf\u00EDa TeX MathJax](%1). Descargue ya instale esta tipograf\u00EDa p'ameyorar la so esperiencia con MathJax."}});MathJax.Ajax.loadComplete("[MathJax]/localization/ast/FontWarnings.js");
